==> Doorstop-0.7.tar.gz: Doorstop-0.7/docs/gen/REQ.md <==
# 1.0 **Composition Features**

## 1.1 REQ003

Doorstop **shall** provide unique and permanent identifiers to linkable sections of text.

*Child links: LLT001, TUT001, TUT002, TUT004, TUT008*

## 1.2 REQ004

Doorstop **shall** support formatting within linkable text.

*Child links: TUT001, TUT002, LLT002*

## 1.3 REQ001

Doorstop **shall** support the storage of external requirements assets.

*Child links: LLT005*

## 1.4 REQ016

Doorstop **shall** be able to import content from other requirments management tools.

*Child links: TUT016, TUT012, TUT013*

## 1.5 REQ017

Doorstop **shall** be able to export content to interact with common text/document tools.

*Child links: TUT015*

# 2.0 **Presentation Features**

## 2.1 REQ007

Doorstop **shall** provide a way to view requirements as a document.

*Child links: TUT009, TUT010, LLT003*

## 2.2 REQ008

Doorstop **shall** provide a way to view document items interactively.

*Child links: LLT004*

## 2.3 REQ009

Doorstop **shall** provide the capability to baseline versions of requirements.

*Child links: LLT007*

# 3.0 **Administration Features**

## 3.1 REQ011

Doorstop **shall** store requirements in a permanent and secure manner.

*Child links: TUT002, TUT004, LLT007*

## 3.2 REQ012

Doorstop **shall** handle change management of the requirements.

*Child links: TUT002, TUT004, LLT007*

## 3.3 REQ013

Doorstop **shall** associate requirements changes to existing developer identification.

*Child links: TUT002, TUT004, LLT007*

## 3.4 REQ014

Doorstop **shall** be scalable to support thousands of requirements.

*Child links: LLT007*

## 3.5 REQ015

Doorstop **shall** provide a lightweight installation method.

*Child links: LLT007, LLT008*

==> Doorstop-0.8.2.tar.gz: Doorstop-0.8.2/docs/gen/REQ.md <==
# 1.0 Composition Features

## 1.1 REQ003

Doorstop **shall** provide unique and permanent identifiers to linkable sections of text.

*Child links: LLT001, TUT001, TUT002, TUT004, TUT008*

## 1.2 REQ004

Doorstop **shall** support formatting within linkable text.

*Child links: TUT001, LLT002, TUT002*

## 1.3 REQ001

Doorstop **shall** support the storage of external requirements assets.

*Child links: LLT005*

## 1.4 REQ016

Doorstop **shall** be able to import content from other requirments management tools.

*Child links: TUT016, TUT012, TUT013*

## 1.5 REQ017

Doorstop **shall** be able to export content to interact with common text/document tools.

*Child links: TUT015*

# 2.0 Presentation Features

## 2.1 REQ007

Doorstop **shall** provide a way to view requirements as a document.

*Child links: LLT003, TUT009, TUT010*

## 2.2 REQ008

Doorstop **shall** provide a way to view document items interactively.

*Child links: LLT004*

## 2.3 REQ009

Doorstop **shall** provide the capability to baseline versions of requirements.

*Child links: LLT007*

# 3.0 Administration Features

## 3.1 REQ011

Doorstop **shall** store requirements in a permanent and secure manner.

*Child links: TUT002, TUT004, LLT007*

## 3.2 REQ012

Doorstop **shall** handle change management of the requirements.

*Child links: TUT002, TUT004, LLT007*

## 3.3 REQ013

Doorstop **shall** associate requirements changes to existing developer identification.

*Child links: TUT002, TUT004, LLT007*

## 3.4 REQ014

Doorstop **shall** be scalable to support thousands of requirements.

*Child links: LLT007*

## 3.5 REQ015

Doorstop **shall** provide a lightweight installation method.

*Child links: LLT007, LLT008*
